==> jc-1.4.0.tar.gz: javax/swing/table/JTableHeader__24AccessibleJTableHeader.h <==
// public class javax.swing.table.JTableHeader$AccessibleJTableHeader

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 3dbfe1b79df9a709 javax_swing_table_JTableHeader__24AccessibleJTableHeader

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_table_JTableHeader__24AccessibleJTableHeader_H_
#define _JC_javax_swing_table_JTableHeader__24AccessibleJTableHeader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_table_JTableHeader$object;

// Typedefs
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object;

typedef const struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods;
typedef const struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable;
typedef const struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype;

// Constructors
extern void _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$method$_init$7b99014f6142737e(_jc_env *, struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object *, struct _jc_javax_swing_table_JTableHeader$object *);

// Virtual methods structure
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods {
};

// Vtable
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods	javax_swing_table_JTableHeader__24AccessibleJTableHeader;
};

// Vtype
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype {
	_jc_type			type;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs {
	struct _jc_javax_swing_table_JTableHeader$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs {
    _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs	javax_swing_table_JTableHeader__24AccessibleJTableHeader;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs	javax_swing_table_JTableHeader__24AccessibleJTableHeader;
};

// Object instance structure
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object {
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype	*vtype;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_table_JTableHeader__24AccessibleJTableHeader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$class_object;

#endif	/* _JC_javax_swing_table_JTableHeader__24AccessibleJTableHeader_H_ */

==> jc-1.4.5.tar.gz: javax/swing/table/JTableHeader__24AccessibleJTableHeader.h <==
// public class javax.swing.table.JTableHeader$AccessibleJTableHeader

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 3dbfe1b79df9a709 javax_swing_table_JTableHeader__24AccessibleJTableHeader

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_table_JTableHeader__24AccessibleJTableHeader_H_
#define _JC_javax_swing_table_JTableHeader__24AccessibleJTableHeader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_table_JTableHeader$object;

// Typedefs
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs;
typedef struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object;

typedef const struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods;
typedef const struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable;
typedef const struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype;

// Constructors
extern void _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$method$_init$7b99014f6142737e(_jc_env *, struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object *, struct _jc_javax_swing_table_JTableHeader$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods {
};

// Vtable
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vmethods	javax_swing_table_JTableHeader__24AccessibleJTableHeader;
};

// Vtype
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype {
	_jc_type			type;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs {
	struct _jc_javax_swing_table_JTableHeader$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs {
    _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_refs	javax_swing_table_JTableHeader__24AccessibleJTableHeader;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$sub_nonrefs	javax_swing_table_JTableHeader__24AccessibleJTableHeader;
};

// Object instance structure
struct _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$object {
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype	*vtype;
	_jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$vtype _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_table_JTableHeader__24AccessibleJTableHeader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_table_JTableHeader__24AccessibleJTableHeader$class_object;

#endif	/* _JC_javax_swing_table_JTableHeader__24AccessibleJTableHeader_H_ */
